OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Hiljutised olekud",
    "No recent status changes" : "Pole hiljutisi olekumuudatusi",
    "In a meeting" : "Koosolekul",
    "Commuting" : "Sõidus",
    "Out sick" : "Haige",
    "Vacationing" : "Puhkusel",
    "Out of office" : "Kontorist väljas",
    "Working remotely" : "Kaugtööl",
    "In a call" : "Kõnes",
    "Be right back" : "Kohe jõuan tagasi",
    "User status" : "Kasutaja olek",
    "Clear status after" : "Eemalda olekuteade peale",
    "Emoji for your status message" : "Sinu olekuteate emoji",
    "What is your status?" : "Mis on su olek?",
    "Predefined statuses" : "Eeldefineeritud olekud",
    "Previously set" : "Varasemalt seatud",
    "Reset status" : "Lähesta olek",
    "Reset status to \"{icon} {message}\"" : "Lähesta olek „{icon} {message}“-ks",
    "Reset status to \"{message}\"" : "Lähesta olek „{message}“-ks",
    "Reset status to \"{icon}\"" : "Lähesta olek „{icon}“-ks",
    "There was an error saving the status" : "Oleku salvestamisel tekkis viga",
    "There was an error clearing the status" : "Oleku eemaldamisel tekkis viga",
    "There was an error reverting the status" : "Oleku taastamisel tekkis viga",
    "Online status" : "Olek võrgus",
    "Status message" : "Olekuteade",
    "Set absence period" : "Määra eemaloleku periood",
    "Set absence period and replacement" : "Määra eemaloleku periood ja asendaja",
    "Your status was set automatically" : "Su olek määrati automaatselt",
    "Clear status message" : "Eemalda olekuteade",
    "Set status message" : "Lisa olekusõnum",
    "Online" : "Võrgus",
    "Away" : "Eemal",
    "Busy" : "Hõivatud",
    "Do not disturb" : "Ära sega",
    "Invisible" : "Nähtamatu",
    "Offline" : "Pole võrgus",
    "Set status" : "Määra olek",
    "There was an error saving the new status" : "Uue oleku salvestamisel esines viga",
    "Don't clear" : "Ära kustuta",
    "30 minutes" : "30 minutit",
    "1 hour" : "1 tundi",
    "4 hours" : "4 tundi",
    "Today" : "Täna",
    "This week" : "Käesoleval nädalal",
    "Mute all notifications" : "Sellega summutad teavitused",
    "Appear offline" : "Sellega paistad olema võrgust väljas"
},
"nplurals=2; plural=(n != 1);");
